==> spring-integration-amqp-5.1.6.RELEASE-sources.jar: org/springframework/integration/amqp/support/EndpointUtils.java <==
/*
 * Copyright 2019 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.integration.amqp.support;

import org.springframework.amqp.core.Message;
import org.springframework.amqp.rabbit.listener.exception.ListenerExecutionFailedException;

import com.rabbitmq.client.Channel;

/**
 * Utility methods for messaging endpoints.
 *
 * @author Gary Russell
 * @since 5.1.3
 *
 */
public final class EndpointUtils {

	private static final String LEFE_MESSAGE = "Message conversion failed";

	private EndpointUtils() {
		super();
	}

	/**
	 * Return an {@link ListenerExecutionFailedException} or a {@link ManualAckListenerExecutionFailedException}
	 * depending on whether isManualAck is false or true.
	 * @param message the failed message.
	 * @param channel the channel.
	 * @param isManualAck true if the container uses manual acknowledgment.
	 * @param e the exception.
	 * @return the exception.
	 */
	public static ListenerExecutionFailedException errorMessagePayload(final Message message,
			Channel channel, boolean isManualAck, Exception e) {

		return isManualAck
				? new ManualAckListenerExecutionFailedException(LEFE_MESSAGE, e, message, channel,
						message.getMessageProperties().getDeliveryTag())
				: new ListenerExecutionFailedException(LEFE_MESSAGE, e, message);
	}

}

==> spring-integration-amqp-5.2.8.RELEASE-sources.jar: org/springframework/integration/amqp/support/EndpointUtils.java <==
/*
 * Copyright 2019 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.integration.amqp.support;

import org.springframework.amqp.core.Message;
import org.springframework.amqp.rabbit.support.ListenerExecutionFailedException;

import com.rabbitmq.client.Channel;

/**
 * Utility methods for messaging endpoints.
 *
 * @author Gary Russell
 *
 * @since 5.1.3
 *
 */
public final class EndpointUtils {

	private static final String LEFE_MESSAGE = "Message conversion failed";

	private EndpointUtils() {
		super();
	}

	/**
	 * Return an {@link ListenerExecutionFailedException} or a {@link ManualAckListenerExecutionFailedException}
	 * depending on whether isManualAck is false or true.
	 * @param message the failed message.
	 * @param channel the channel.
	 * @param isManualAck true if the container uses manual acknowledgment.
	 * @param e the exception.
	 * @return the exception.
	 */
	public static ListenerExecutionFailedException errorMessagePayload(final Message message,
			Channel channel, boolean isManualAck, Exception e) {

		return isManualAck
				? new ManualAckListenerExecutionFailedException(LEFE_MESSAGE, e, message, channel,
						message.getMessageProperties().getDeliveryTag())
				: new ListenerExecutionFailedException(LEFE_MESSAGE, e, message);
	}

}
